@@ -2,7 +2,7 @@
 
   error.c -
 
-  $Author$
+  $Author: nagachika $
   created at: Mon Aug  9 16:11:34 JST 1993
 
   Copyright (C) 1993-2007 Yukihiro Matsumoto
@@ -43,12 +43,17 @@ VALUE rb_eEINPROGRESS;
 
 extern const char ruby_description[];
 
-#define REPORTBUG_MSG \
+static const char REPORTBUG_MSG[] =
 	"[NOTE]\n" \
 	"You may have encountered a bug in the Ruby interpreter" \
 	" or extension libraries.\n" \
 	"Bug reports are welcome.\n" \
+	""
+#if defined __APPLE__
+	"Don't forget to include the above Crash Report log file.\n"
+#endif
 	"For details: http://www.ruby-lang.org/bugreport.html\n\n" \
+    ;
 
 static const char *
 rb_strerrno(int err)
@@ -1735,14 +1740,18 @@ syserr_eqq(VALUE self, VALUE exc)
  *    * LoadError
  *    * NotImplementedError
  *    * SyntaxError
+ *  * SecurityError
  *  * SignalException
  *    * Interrupt
  *  * StandardError -- default for +rescue+
  *    * ArgumentError
- *    * IndexError
- *      * StopIteration
+ *    * EncodingError
+ *    * FiberError
  *    * IOError
  *      * EOFError
+ *    * IndexError
+ *      * KeyError
+ *      * StopIteration
  *    * LocalJumpError
  *    * NameError
  *      * NoMethodError
@@ -1750,14 +1759,13 @@ syserr_eqq(VALUE self, VALUE exc)
  *      * FloatDomainError
  *    * RegexpError
  *    * RuntimeError -- default for +raise+
- *    * SecurityError
  *    * SystemCallError
  *      * Errno::*
- *    * SystemStackError
  *    * ThreadError
  *    * TypeError
  *    * ZeroDivisionError
  *  * SystemExit
+ *  * SystemStackError
  *  * fatal -- impossible to rescue
  */
 
